==> ba-react-fetch-api-0.9.6.tgz: package/FetchAPI/reducers.js <==
// @flow
import _ from 'lodash';
import {combineReducers} from 'redux';
import rest from './rest';
import type {TSourceItem, TFetchedArray, TFetchedObject} from './flow-typed';
import {actionTypes as optimisticTypes} from './helpers/with-optimistic'

export default (sources: Array<TSourceItem>) => combineReducers(_.reduce(sources, (reducers, source) => ({
	...reducers,

	[source.key]: (state: TFetchedArray | TFetchedObject = {data: [], loading: false}, action) => {
		let

			/* eslint-disable sort-vars */
			restSource = rest(source),
			newState = restSource.reducers[source.key](state, action);

		if(_.isArray(source.reducers))
			newState = _.reduce(source.reducers, (resultState, reducer) => reducer(resultState, action), newState);

		/* eslint-enable sort-vars */
		if(action.type === restSource.events[source.key].actionSuccess)
			return {
				...newState,
				lastResponse: action.origData,
			};

		if(action.type === optimisticTypes.optimisticUpdate && _.includes(action.updateKeys, source.key))
			return (_.isFunction(action.update)
				? action.update
				: action.update[source.key]
			)({...newState, stateBeforeUpdate: newState});

		if(action.type === optimisticTypes.optimisticFailed && _.includes(action.updateKeys, source.key))
			return {...(newState.optimistic ? newState.stateBeforeUpdate : newState)};

		if(action.type === optimisticTypes.optimisticSuccess && _.includes(action.updateKeys, source.key))
			return _.omit(action.commit(newState, action.response), ['stateBeforeUpdate']);

		return newState;
	},
}), {}));

==> ba-react-fetch-api-0.12.54.tgz: package/FetchAPI/reducers.js <==
// @flow
import _ from 'lodash';
import {combineReducers} from 'redux';
import rest from './rest';
import type {TSourceItem, TFetchedArray, TFetchedObject} from './flow-typed';
import {actionTypes as optimisticTypes} from './helpers/with-optimistic'

export default (sources: Array<TSourceItem>) => combineReducers(_.reduce(sources, (reducers, source) => ({
	...reducers,

	[source.key]: (state: TFetchedArray | TFetchedObject = {data: [], loading: false}, action) => {
		let

			/* eslint-disable sort-vars */
			restSource = rest(source),
			newState = restSource.reducers[source.key](state, action);

		if(_.isArray(source.reducers))
			newState = _.reduce(source.reducers, (resultState, reducer) => reducer(resultState, action), newState);

		/* eslint-enable sort-vars */
		if(action.type === restSource.events[source.key].actionSuccess)
			return {
				...newState,
				lastResponse: action.origData,
			};

		if(action.type === optimisticTypes.optimisticUpdate && _.includes(action.updateKeys, source.key))
			return (_.isFunction(action.update)
				? action.update
				: action.update[source.key]
			)({...newState, stateBeforeUpdate: newState});

		if(action.type === optimisticTypes.optimisticFailed && _.includes(action.updateKeys, source.key))
			return {...(newState.stateBeforeUpdate ? newState.stateBeforeUpdate : newState)};

		if(action.type === optimisticTypes.optimisticSuccess && _.includes(action.updateKeys, source.key))
			return _.omit(action.commit(newState, action.response), ['stateBeforeUpdate']);

		return newState;
	},
}), {}));
